==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.cl == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.cl.count; d++) {
            var e = Math.abs(a.tn[d]) + a.tm[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.tn[d] / e * 100);
            c = Math.max(c, a.tm[d] / e * 100);
        }
        a.t4 = b;
        a.t3 = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.c6 == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.c6.count; d++) {
            var e = Math.abs(a.xd[d]) + a.xc[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.xd[d] / e * 100);
            c = Math.max(c, a.xc[d] / e * 100);
        }
        a.xu = b;
        a.xt = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };
